@@ -145,6 +145,8 @@ static guint brasero_burn_signals [LAST_SIGNAL] = { 0 };
 
 #define MAX_EJECT_ATTEMPTS	5
 #define MAX_MOUNT_ATTEMPTS	40
+#define MAX_REPROBE_ATTEMPTS	80
+
 #define MOUNT_TIMEOUT		500
 
 static GObjectClass *parent_class = NULL;
@@ -257,6 +259,7 @@ brasero_burn_sleep (BraseroBurn *burn, gint msec)
 static BraseroBurnResult
 brasero_burn_reprobe (BraseroBurn *burn)
 {
+	guint attempts = 0;
 	BraseroMedium *medium;
 	BraseroBurnPrivate *priv;
 	BraseroBurnResult result = BRASERO_BURN_OK;
@@ -267,8 +270,10 @@ brasero_burn_reprobe (BraseroBurn *burn)
 
 	/* reprobe the medium and wait for it to be probed */
 	brasero_drive_reprobe (priv->dest);
-	while ((medium = brasero_drive_get_medium (priv->dest)) == NULL)
+	while (attempts < MAX_REPROBE_ATTEMPTS && (medium = brasero_drive_get_medium (priv->dest)) == NULL) {
 		result = brasero_burn_sleep (burn, 250);
+		attempts ++;
+	}
 
 	return result;
 }
@@ -1754,6 +1759,9 @@ brasero_burn_run_tasks (BraseroBurn *burn,
 
 	/* run all imaging tasks first */
 	for (iter = tasks; iter; iter = next) {
+		goffset len = 0;
+		BraseroDrive *drive;
+		BraseroMedium *medium;
 		BraseroTaskAction action;
 
 		next = iter->next;
@@ -1813,29 +1821,23 @@ brasero_burn_run_tasks (BraseroBurn *burn,
 			break;
 
 		/* try to get the output size */
-		if (BRASERO_MEDIUM_RANDOM_WRITABLE (brasero_burn_session_get_dest_media (priv->session))) {
-			goffset len = 0;
-			BraseroDrive *drive;
-			BraseroMedium *medium;
+		brasero_task_ctx_get_session_output_size (BRASERO_TASK_CTX (priv->task),
+							  &len,
+							  NULL);
 
-			brasero_task_ctx_get_session_output_size (BRASERO_TASK_CTX (priv->task),
-								  &len,
-								  NULL);
+		drive = brasero_burn_session_get_burner (priv->session);
+		medium = brasero_drive_get_medium (drive);
 
-			drive = brasero_burn_session_get_burner (priv->session);
-			medium = brasero_drive_get_medium (drive);
+		if (brasero_burn_session_get_flags (priv->session) & (BRASERO_BURN_FLAG_MERGE|BRASERO_BURN_FLAG_APPEND))
+			priv->session_start = brasero_medium_get_next_writable_address (medium);
+		else
+			priv->session_start = 0;
 
-			if (brasero_burn_session_get_flags (priv->session) & (BRASERO_BURN_FLAG_MERGE|BRASERO_BURN_FLAG_APPEND))
-				priv->session_start = brasero_medium_get_next_writable_address (medium);
-			else
-				priv->session_start = 0;
+		priv->session_end = priv->session_start + len;
 
-			priv->session_end = priv->session_start + len;
-
-			BRASERO_BURN_LOG ("Burning from %lld to %lld",
-					  priv->session_start,
-					  priv->session_end);
-		}
+		BRASERO_BURN_LOG ("Burning from %lld to %lld",
+				  priv->session_start,
+				  priv->session_end);
 
 		/* see if we reached a recording task: it's the last task */
 		if (!next) {
@@ -2086,6 +2088,7 @@ brasero_burn_record_session (BraseroBurn *burn,
 			     gboolean erase_allowed,
 			     GError **error)
 {
+	const gchar *checksum = NULL;
 	BraseroBurnFlag session_flags;
 	BraseroTrack *track = NULL;
 	BraseroChecksumType type;
@@ -2187,38 +2190,25 @@ brasero_burn_record_session (BraseroBurn *burn,
 
 	if (type == BRASERO_CHECKSUM_MD5
 	||  type == BRASERO_CHECKSUM_SHA1
-	||  type == BRASERO_CHECKSUM_SHA256) {
-		const gchar *checksum = NULL;
-
+	||  type == BRASERO_CHECKSUM_SHA256)
 		checksum = brasero_track_get_checksum (track);
+	else if (type == BRASERO_CHECKSUM_MD5_FILE)
+		checksum = BRASERO_MD5_FILE;
+	else if (type == BRASERO_CHECKSUM_SHA1_FILE)
+		checksum = BRASERO_SHA1_FILE;
+	else if (type == BRASERO_CHECKSUM_SHA256_FILE)
+		checksum = BRASERO_SHA256_FILE;
 
-		/* the idea is to push a new track on the stack with
-		 * the current disc burnt and the checksum generated
-		 * during the session recording */
-		track = BRASERO_TRACK (brasero_track_disc_new ());
-		brasero_track_set_checksum (BRASERO_TRACK (track), type, checksum);
-	}
-	else if (type == BRASERO_CHECKSUM_MD5_FILE) {
-		track = BRASERO_TRACK (brasero_track_disc_new ());
-		brasero_track_set_checksum (BRASERO_TRACK (track),
-					    type,
-					    BRASERO_MD5_FILE);
-	}
-	else if (type == BRASERO_CHECKSUM_SHA1_FILE) {
-		track = BRASERO_TRACK (brasero_track_disc_new ());
-		brasero_track_set_checksum (BRASERO_TRACK (track),
-					    type,
-					    BRASERO_SHA1_FILE);
-	}
-	else if (type == BRASERO_CHECKSUM_SHA256_FILE) {
-		track = BRASERO_TRACK (brasero_track_disc_new ());
-		brasero_track_set_checksum (BRASERO_TRACK (track),
-					    type,
-					    BRASERO_SHA256_FILE);
-	}
-
+	/* the idea is to push a new track on the stack with
+	 * the current disc burnt and the checksum generated
+	 * during the session recording */
 	brasero_burn_session_push_tracks (priv->session);
 
+	track = BRASERO_TRACK (brasero_track_disc_new ());
+	brasero_track_set_checksum (BRASERO_TRACK (track),
+	                            type,
+	                            checksum);
+
 	brasero_track_disc_set_drive (BRASERO_TRACK_DISC (track), brasero_burn_session_get_burner (priv->session));
 	brasero_burn_session_add_track (priv->session, track, NULL);
 
@@ -2226,6 +2216,8 @@ brasero_burn_record_session (BraseroBurn *burn,
 	 * anymore. BraseroBurnSession refs it. */
 	g_object_unref (track);
 
+	BRASERO_BURN_DEBUG (burn, "Preparing to checksum (type %i %s)", type, checksum);
+
 	/* this may be necessary for the drive to settle down and possibly be
 	 * mounted by gnome-volume-manager (just temporarily) */
 	result = brasero_burn_sleep (burn, 5000);
@@ -2243,45 +2235,37 @@ brasero_burn_record_session (BraseroBurn *burn,
 
 	medium = brasero_drive_get_medium (priv->dest);
 
+	/* Why do we do this?
+	 * Because for a lot of medium types the size
+	 * of the track return is not the real size of the
+	 * data that was written; examples
+	 * - CD that was written in SAO mode 
+	 * - a DVD-R which usually aligns its track size
+	 *   to a 16 block boundary
+	 */
 	if (type == BRASERO_CHECKSUM_MD5
 	||  type == BRASERO_CHECKSUM_SHA1
 	||  type == BRASERO_CHECKSUM_SHA256) {
-		BraseroMedia media;
+		GValue *value;
 
-		/* get the last written track address in case of DVD+RW/DVD-RW
-		 * restricted overwrite since there is no such thing as track
-		 * number for these drives. */
-		media = brasero_medium_get_status (medium);
+		/* get the last written track address */
+		value = g_new0 (GValue, 1);
+		g_value_init (value, G_TYPE_UINT64);
 
-		if (!BRASERO_MEDIUM_RANDOM_WRITABLE (media)) {
-			guint track_num;
+		BRASERO_BURN_LOG ("Start of last written track address == %lli", priv->session_start);
+		g_value_set_uint64 (value, priv->session_start);
+		brasero_track_tag_add (track,
+				       BRASERO_TRACK_MEDIUM_ADDRESS_START_TAG,
+				       value);
 
-			track_num = brasero_medium_get_track_num (medium);
+		value = g_new0 (GValue, 1);
+		g_value_init (value, G_TYPE_UINT64);
 
-			BRASERO_BURN_LOG ("Last written track num == %i", track_num);
-			brasero_track_disc_set_track_num (BRASERO_TRACK_DISC (track), track_num);
-		}
-		else {
-			GValue *value;
-
-			value = g_new0 (GValue, 1);
-			g_value_init (value, G_TYPE_UINT64);
-
-			BRASERO_BURN_LOG ("Start of last written track address == %lli", priv->session_start);
-			g_value_set_uint64 (value, priv->session_start);
-			brasero_track_tag_add (track,
-					       BRASERO_TRACK_MEDIUM_ADDRESS_START_TAG,
-					       value);
-
-			value = g_new0 (GValue, 1);
-			g_value_init (value, G_TYPE_UINT64);
-
-			BRASERO_BURN_LOG ("End of last written track address == %lli", priv->session_end);
-			g_value_set_uint64 (value, priv->session_end);
-			brasero_track_tag_add (track,
-					       BRASERO_TRACK_MEDIUM_ADDRESS_END_TAG,
-					       value);
-		}
+		BRASERO_BURN_LOG ("End of last written track address == %lli", priv->session_end);
+		g_value_set_uint64 (value, priv->session_end);
+		brasero_track_tag_add (track,
+				       BRASERO_TRACK_MEDIUM_ADDRESS_END_TAG,
+				       value);
 	}
 
 	result = brasero_burn_check_real (burn, track, error);
