@@ -280,7 +280,50 @@ brasero_marshal_INT__POINTER_BOOLEAN (GClosure     *closure,
   g_value_set_int (return_value, v_return);
 }
 
-/* BOOLEAN:STRING (./libbrasero-marshal.list:6) */
+/* BOOLEAN:VOID (./libbrasero-marshal.list:6) */
+extern void brasero_marshal_BOOLEAN__VOID (GClosure     *closure,
+                                           GValue       *return_value,
+                                           guint         n_param_values,
+                                           const GValue *param_values,
+                                           gpointer      invocation_hint,
+                                           gpointer      marshal_data);
+void
+brasero_marshal_BOOLEAN__VOID (GClosure     *closure,
+                               GValue       *return_value G_GNUC_UNUSED,
+                               guint         n_param_values,
+                               const GValue *param_values,
+                               gpointer      invocation_hint G_GNUC_UNUSED,
+                               gpointer      marshal_data)
+{
+  typedef gboolean (*GMarshalFunc_BOOLEAN__VOID) (gpointer     data1,
+                                                  gpointer     data2);
+  register GMarshalFunc_BOOLEAN__VOID callback;
+  register GCClosure *cc = (GCClosure*) closure;
+  register gpointer data1, data2;
+  gboolean v_return;
+
+  g_return_if_fail (return_value != NULL);
+  g_return_if_fail (n_param_values == 1);
+
+  if (G_CCLOSURE_SWAP_DATA (closure))
+    {
+      data1 = closure->data;
+      data2 = g_value_peek_pointer (param_values + 0);
+    }
+  else
+    {
+      data1 = g_value_peek_pointer (param_values + 0);
+      data2 = closure->data;
+    }
+  callback = (GMarshalFunc_BOOLEAN__VOID) (marshal_data ? marshal_data : cc->callback);
+
+  v_return = callback (data1,
+                       data2);
+
+  g_value_set_boolean (return_value, v_return);
+}
+
+/* BOOLEAN:STRING (./libbrasero-marshal.list:7) */
 extern void brasero_marshal_BOOLEAN__STRING (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
@@ -325,7 +368,7 @@ brasero_marshal_BOOLEAN__STRING (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:POINTER (./libbrasero-marshal.list:7) */
+/* BOOLEAN:POINTER (./libbrasero-marshal.list:8) */
 extern void brasero_marshal_BOOLEAN__POINTER (GClosure     *closure,
                                               GValue       *return_value,
                                               guint         n_param_values,
@@ -370,7 +413,7 @@ brasero_marshal_BOOLEAN__POINTER (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* VOID:INT,STRING (./libbrasero-marshal.list:8) */
+/* VOID:INT,STRING (./libbrasero-marshal.list:9) */
 extern void brasero_marshal_VOID__INT_STRING (GClosure     *closure,
                                               GValue       *return_value,
                                               guint         n_param_values,
@@ -413,7 +456,7 @@ brasero_marshal_VOID__INT_STRING (GClosure     *closure,
             data2);
 }
 
-/* VOID:POINTER,STRING (./libbrasero-marshal.list:9) */
+/* VOID:POINTER,STRING (./libbrasero-marshal.list:10) */
 extern void brasero_marshal_VOID__POINTER_STRING (GClosure     *closure,
                                                   GValue       *return_value,
                                                   guint         n_param_values,
@@ -456,7 +499,7 @@ brasero_marshal_VOID__POINTER_STRING (GClosure     *closure,
             data2);
 }
 
-/* VOID:POINTER,POINTER (./libbrasero-marshal.list:10) */
+/* VOID:POINTER,POINTER (./libbrasero-marshal.list:11) */
 extern void brasero_marshal_VOID__POINTER_POINTER (GClosure     *closure,
                                                    GValue       *return_value,
                                                    guint         n_param_values,
@@ -499,7 +542,7 @@ brasero_marshal_VOID__POINTER_POINTER (GClosure     *closure,
             data2);
 }
 
-/* VOID:OBJECT,BOOLEAN (./libbrasero-marshal.list:11) */
+/* VOID:OBJECT,BOOLEAN (./libbrasero-marshal.list:12) */
 extern void brasero_marshal_VOID__OBJECT_BOOLEAN (GClosure     *closure,
                                                   GValue       *return_value,
                                                   guint         n_param_values,
@@ -542,7 +585,7 @@ brasero_marshal_VOID__OBJECT_BOOLEAN (GClosure     *closure,
             data2);
 }
 
-/* VOID:OBJECT,UINT (./libbrasero-marshal.list:12) */
+/* VOID:OBJECT,UINT (./libbrasero-marshal.list:13) */
 extern void brasero_marshal_VOID__OBJECT_UINT (GClosure     *closure,
                                                GValue       *return_value,
                                                guint         n_param_values,
@@ -585,7 +628,7 @@ brasero_marshal_VOID__OBJECT_UINT (GClosure     *closure,
             data2);
 }
 
-/* VOID:BOOLEAN,BOOLEAN (./libbrasero-marshal.list:13) */
+/* VOID:BOOLEAN,BOOLEAN (./libbrasero-marshal.list:14) */
 extern void brasero_marshal_VOID__BOOLEAN_BOOLEAN (GClosure     *closure,
                                                    GValue       *return_value,
                                                    guint         n_param_values,
@@ -628,7 +671,7 @@ brasero_marshal_VOID__BOOLEAN_BOOLEAN (GClosure     *closure,
             data2);
 }
 
-/* VOID:DOUBLE,DOUBLE,LONG (./libbrasero-marshal.list:14) */
+/* VOID:DOUBLE,DOUBLE,LONG (./libbrasero-marshal.list:15) */
 extern void brasero_marshal_VOID__DOUBLE_DOUBLE_LONG (GClosure     *closure,
                                                       GValue       *return_value,
                                                       guint         n_param_values,
@@ -673,7 +716,7 @@ brasero_marshal_VOID__DOUBLE_DOUBLE_LONG (GClosure     *closure,
             data2);
 }
 
-/* VOID:POINTER,UINT,POINTER (./libbrasero-marshal.list:15) */
+/* VOID:POINTER,UINT,POINTER (./libbrasero-marshal.list:16) */
 extern void brasero_marshal_VOID__POINTER_UINT_POINTER (GClosure     *closure,
                                                         GValue       *return_value,
                                                         guint         n_param_values,
