@@ -39,31 +39,25 @@
 
 #include <gio/gio.h>
 
-#include <dbus/dbus.h>
-#include <dbus/dbus-glib.h>
-#include <dbus/dbus-glib-lowlevel.h>
-
-#include <libhal.h>
-
 #include "brasero-media-private.h"
 
+#include "scsi-device.h"
+#include "scsi-utils.h"
+#include "scsi-spc1.h"
+
 #include "brasero-drive.h"
 #include "brasero-medium.h"
-#include "burn-hal-watch.h"
 #include "brasero-medium-monitor.h"
 
-#if defined(HAVE_STRUCT_USCSI_CMD)
-#define BLOCK_DEVICE	"block.solaris.raw_device"
-#else
-#define BLOCK_DEVICE	"block.device"
-#endif
-
 typedef struct _BraseroMediumMonitorPrivate BraseroMediumMonitorPrivate;
 struct _BraseroMediumMonitorPrivate
 {
 	GSList *drives;
 	GVolumeMonitor *gmonitor;
 
+	GSList *waiting_removal;
+	guint waiting_removal_id;
+
 	gint probing;
 };
 
@@ -90,9 +84,6 @@ G_DEFINE_TYPE (BraseroMediumMonitor, brasero_medium_monitor, G_TYPE_OBJECT);
  * here.
  */
 
-BraseroDrive *
-brasero_drive_new (const gchar *udi);
-
 gboolean
 brasero_drive_probing (BraseroDrive *drive);
 
@@ -103,7 +94,7 @@ brasero_drive_probing (BraseroDrive *drive);
  *
  * Returns the #BraseroDrive object whose path is @path.
  *
- * Return value: a #BraseroDrive or NULL
+ * Return value: a #BraseroDrive or NULL. It should be unreffed when no longer in use.
  **/
 BraseroDrive *
 brasero_medium_monitor_get_drive (BraseroMediumMonitor *monitor,
@@ -113,6 +104,7 @@ brasero_medium_monitor_get_drive (BraseroMediumMonitor *monitor,
 	BraseroMediumMonitorPrivate *priv;
 
 	g_return_val_if_fail (monitor != NULL, NULL);
+	g_return_val_if_fail (device != NULL, NULL);
 	g_return_val_if_fail (BRASERO_IS_MEDIUM_MONITOR (monitor), NULL);
 
 	priv = BRASERO_MEDIUM_MONITOR_PRIVATE (monitor);
@@ -285,7 +277,12 @@ brasero_medium_monitor_get_media (BraseroMediumMonitor *monitor,
 		}
 
 		if (type & BRASERO_MEDIA_TYPE_FILE) {
-			if (brasero_medium_get_status (medium) & BRASERO_MEDIUM_FILE) {
+			/* make sure the drive is indeed a fake one
+			 * since it can happen that some medium did
+			 * not properly carry out their initialization 
+			 * and are flagged as BRASERO_MEDIUM_FILE
+			 * whereas they are not */
+			if (brasero_drive_is_fake (drive)) {
 				list = g_slist_prepend (list, medium);
 				g_object_ref (medium);
 			}
@@ -317,24 +314,69 @@ brasero_medium_monitor_medium_removed_cb (BraseroDrive *drive,
 		       medium);
 }
 
+static gboolean
+brasero_medium_monitor_is_drive (BraseroMediumMonitor *monitor,
+                                 const gchar *device)
+{
+	BraseroMediumMonitorPrivate *priv;
+	BraseroDeviceHandle *handle;
+	BraseroScsiErrCode code;
+	gboolean result;
+
+	priv = BRASERO_MEDIUM_MONITOR_PRIVATE (monitor);
+
+	BRASERO_MEDIA_LOG ("Testing drive %s", device);
+
+	handle = brasero_device_handle_open (device, FALSE, &code);
+	if (!handle)
+		return FALSE;
+
+	result = (brasero_spc1_inquiry_is_optical_drive (handle, &code) == BRASERO_SCSI_OK);
+	brasero_device_handle_close (handle);
+
+	BRASERO_MEDIA_LOG ("Drive %s", result? "is optical":"is not optical");
+
+	return result;
+}
+
 static void
-brasero_medium_monitor_inserted_cb (BraseroHALWatch *watch,
-				    const char *udi,
-				    BraseroMediumMonitor *self)
+brasero_medium_monitor_device_added (BraseroMediumMonitor *self,
+                                     const gchar *device,
+                                     GDrive *gdrive)
 {
 	BraseroMediumMonitorPrivate *priv;
 	BraseroDrive *drive = NULL;
-	LibHalContext *ctx;
 
-	ctx = brasero_hal_watch_get_ctx (watch);
-	if (!libhal_device_query_capability (ctx, udi, "storage.cdrom", NULL))
+	priv = BRASERO_MEDIUM_MONITOR_PRIVATE (self);
+
+	/* See if the drive is waiting removal.
+	 * This is necessary as GIO behaves strangely sometimes
+	 * since it sends the "disconnected" signal when a medium
+	 * is removed soon followed by a "connected" signal */
+	drive = brasero_medium_monitor_get_drive (self, device);
+	if (drive) {
+		/* Just in case that drive was waiting removal */
+		priv->waiting_removal = g_slist_remove (priv->waiting_removal, drive);
+
+		BRASERO_MEDIA_LOG ("Added signal was emitted but the drive is in the removal list. Updating GDrive associated object.");
+		g_object_set (drive,
+		              "gdrive", gdrive,
+		              NULL);
+
+		g_object_unref (drive);
+		return;
+	}
+
+	/* Make sure it's an optical drive */
+	if (!brasero_medium_monitor_is_drive (self, device))
 		return;
 
 	BRASERO_MEDIA_LOG ("New drive added");
 
-	priv = BRASERO_MEDIUM_MONITOR_PRIVATE (self);
-
-	drive = brasero_drive_new (udi);
+	drive = g_object_new (BRASERO_TYPE_DRIVE,
+	                      "device", device,
+	                      "gdrive", gdrive,
+	                      NULL);
 	priv->drives = g_slist_prepend (priv->drives, drive);
 
 	/* connect to signals. This must come before the g_signal_emit () so we
@@ -362,113 +404,290 @@ brasero_medium_monitor_inserted_cb (BraseroHALWatch *watch,
 }
 
 static void
-brasero_medium_monitor_removed_cb (BraseroHALWatch *watch,
-				   const char *udi,
-				   BraseroMediumMonitor *self)
+brasero_medium_monitor_connected_cb (GVolumeMonitor *monitor,
+                                     GDrive *gdrive,
+                                     BraseroMediumMonitor *self)
 {
+	gchar *device;
+
+	BRASERO_MEDIA_LOG ("GDrive addition signal");
+
+	device = g_drive_get_identifier (gdrive, G_VOLUME_IDENTIFIER_KIND_UNIX_DEVICE);
+	brasero_medium_monitor_device_added (self, device, gdrive);
+	g_free (device);
+}
+
+static void
+brasero_medium_monitor_volume_added_cb (GVolumeMonitor *monitor,
+                                        GVolume *gvolume,
+                                        BraseroMediumMonitor *self)
+{
+	gchar *device;
+	GDrive *gdrive;
+
+	BRASERO_MEDIA_LOG ("GVolume addition signal");
+
+	/* No need to signal that addition if the GVolume
+	 * object has an associated GDrive as this is just
+	 * meant to trap blank discs which have no GDrive
+	 * associated but a GVolume. */
+	gdrive = g_volume_get_drive (gvolume);
+	if (gdrive) {
+		g_object_unref (gdrive);
+		return;
+	}
+
+	device = g_volume_get_identifier (gvolume, G_VOLUME_IDENTIFIER_KIND_UNIX_DEVICE);
+	if  (!device)
+		return;
+
+	brasero_medium_monitor_device_added (self, device, NULL);
+	g_free (device);
+}
+
+static gboolean
+brasero_medium_monitor_disconnected_real (gpointer data)
+{
+	BraseroMediumMonitor *self = BRASERO_MEDIUM_MONITOR (data);
 	BraseroMediumMonitorPrivate *priv;
-	LibHalContext *ctx;
-	GSList *iter;
-	GSList *next;
+	BraseroMedium *medium;
+	BraseroDrive *drive;
 
-	ctx = brasero_hal_watch_get_ctx (watch);
 	priv = BRASERO_MEDIUM_MONITOR_PRIVATE (self);
 
-	BRASERO_MEDIA_LOG ("Drive removed");
-
-	for (iter = priv->drives; iter; iter = next) {
-		const gchar *device_udi;
-		BraseroDrive *drive;
-
-		drive = iter->data;
-		next = iter->next;
-
-		device_udi = brasero_drive_get_udi (drive);
-		if (!device_udi)
-			continue;
-
-		if (!strcmp (device_udi, udi)) {
-			BraseroMedium *medium;
-
-			medium = brasero_drive_get_medium (drive);
-			if (medium)
-				g_signal_emit (self,
-					       medium_monitor_signals [MEDIUM_REMOVED],
-					       0,
-					       medium);
-
-			priv->drives = g_slist_remove (priv->drives, drive);
-			g_signal_emit (self,
-				       medium_monitor_signals [DRIVE_REMOVED],
-				       0,
-				       drive);
-			g_object_unref (drive);
-		}
+	if (!priv->waiting_removal) {
+		priv->waiting_removal_id = 0;
+		return FALSE;
 	}
+
+	drive = priv->waiting_removal->data;
+	priv->waiting_removal = g_slist_remove (priv->waiting_removal, drive);
+
+	BRASERO_MEDIA_LOG ("Drive removed");
+	medium = brasero_drive_get_medium (drive);
+
+	/* disconnect the signal handlers to avoid having the "medium-removed" fired twice */
+	g_signal_handlers_disconnect_by_func (drive,
+	                                      brasero_medium_monitor_medium_added_cb,
+	                                      self);
+	g_signal_handlers_disconnect_by_func (drive,
+	                                      brasero_medium_monitor_medium_removed_cb,
+	                                      self);
+
+	if (medium)
+		g_signal_emit (self,
+			       medium_monitor_signals [MEDIUM_REMOVED],
+			       0,
+			       medium);
+
+	priv->drives = g_slist_remove (priv->drives, drive);
+	g_signal_emit (self,
+		       medium_monitor_signals [DRIVE_REMOVED],
+		       0,
+		       drive);
+	g_object_unref (drive);
+
+	/* in case there are more */
+	return TRUE;
+}
+
+static void
+brasero_medium_monitor_device_removed (BraseroMediumMonitor *self,
+                                       const gchar *device,
+                                       GDrive *gdrive)
+{
+	BraseroMediumMonitorPrivate *priv;
+	GDrive *associated_gdrive;
+	BraseroDrive *drive;
+
+	priv = BRASERO_MEDIUM_MONITOR_PRIVATE (self);
+
+	/* Make sure it's one already detected */
+	/* GIO behaves strangely: every time a medium 
+	 * is removed from a drive it emits the disconnected
+	 * signal (which IMO it shouldn't) soon followed by
+	 * a connected signal.
+	 * So delay the removal by one or two seconds. */
+
+	drive = brasero_medium_monitor_get_drive (self, device);
+	if (!drive)
+		return;
+
+	if (G_UNLIKELY (g_slist_find (priv->waiting_removal, drive) != NULL)) {
+		g_object_unref (drive);
+		return;
+	}
+
+	associated_gdrive = brasero_drive_get_gdrive (drive);
+	if (associated_gdrive == gdrive) {
+		BRASERO_MEDIA_LOG ("Found device to remove");
+		priv->waiting_removal = g_slist_append (priv->waiting_removal, drive);
+
+		if (!priv->waiting_removal_id)
+			priv->waiting_removal_id = g_timeout_add_seconds (2,
+			                                                  brasero_medium_monitor_disconnected_real, 
+			                                                  self);
+	}
+	else if (associated_gdrive) {
+		/* do nothing and wait for a "drive-disconnected" signal */
+		g_object_unref (associated_gdrive);
+	}
+
+	g_object_unref (drive);
+}
+
+static void
+brasero_medium_monitor_volume_removed_cb (GVolumeMonitor *monitor,
+                                          GVolume *gvolume,
+                                          BraseroMediumMonitor *self)
+{
+	gchar *device;
+	GDrive *gdrive;
+
+	BRASERO_MEDIA_LOG ("Volume removal signal");
+
+	/* No need to signal that removal if the GVolume
+	 * object has an associated GDrive as this is just
+	 * meant to trap blank discs which have no GDrive
+	 * associated but a GVolume. */
+	gdrive = g_volume_get_drive (gvolume);
+	if (gdrive) {
+		g_object_unref (gdrive);
+		return;
+	}
+
+	device = g_volume_get_identifier (gvolume, G_VOLUME_IDENTIFIER_KIND_UNIX_DEVICE);
+	if (!device)
+		return;
+
+	brasero_medium_monitor_device_removed (self, device, NULL);
+	g_free (device);
+}
+
+static void
+brasero_medium_monitor_disconnected_cb (GVolumeMonitor *monitor,
+                                        GDrive *gdrive,
+                                        BraseroMediumMonitor *self)
+{
+	gchar *device;
+
+	BRASERO_MEDIA_LOG ("Drive removal signal");
+
+	device = g_drive_get_identifier (gdrive, G_VOLUME_IDENTIFIER_KIND_UNIX_DEVICE);
+	brasero_medium_monitor_device_removed (self, device, gdrive);
+	g_free (device);
 }
 
 static void
 brasero_medium_monitor_init (BraseroMediumMonitor *object)
 {
-	DBusError error;
-	int nb_devices, i;
-	LibHalContext *ctx;
+	GList *iter;
+	GList *drives;
+	GList *volumes;
 	BraseroDrive *drive;
-	char **devices = NULL;
-	BraseroHALWatch *watch;
 	BraseroMediumMonitorPrivate *priv;
 
 	priv = BRASERO_MEDIUM_MONITOR_PRIVATE (object);
 
-	/* This must done early on. GVolumeMonitor when it relies on HAL (like
-	 * us) must be able to update its list of volumes before us so it must
-	 * connect to HAL before us. */
+	BRASERO_MEDIA_LOG ("Probing drives and media");
+
 	priv->gmonitor = g_volume_monitor_get ();
 
-	watch = brasero_hal_watch_get_default ();
-	ctx = brasero_hal_watch_get_ctx (watch);
+	drives = g_volume_monitor_get_connected_drives (priv->gmonitor);
+	BRASERO_MEDIA_LOG ("Found %d drives", g_list_length (drives));
 
-	g_signal_connect (watch,
-			  "device-added",
-			  G_CALLBACK (brasero_medium_monitor_inserted_cb),
-			  object);
-	g_signal_connect (watch,
-			  "device-removed",
-			  G_CALLBACK (brasero_medium_monitor_removed_cb),
-			  object);
+	for (iter = drives; iter; iter = iter->next) {
+		GDrive *gdrive;
+		gchar *device;
 
-	/* Now we get the list and cache it */
-	dbus_error_init (&error);
-	BRASERO_MEDIA_LOG ("Polling for drives");
-	devices = libhal_find_device_by_capability (ctx,
-						    "storage.cdrom", &nb_devices,
-						    &error);
-	if (dbus_error_is_set (&error)) {
-		BRASERO_MEDIA_LOG ("Hal is not running : %s\n", error.message);
-		dbus_error_free (&error);
-		return;
+		gdrive = iter->data;
+
+		device = g_drive_get_identifier (gdrive, G_VOLUME_IDENTIFIER_KIND_UNIX_DEVICE);
+		if (brasero_medium_monitor_is_drive (object, device)) {
+			drive = g_object_new (BRASERO_TYPE_DRIVE,
+			                      "device", device,
+					      "gdrive", gdrive,
+					      NULL);
+
+			priv->drives = g_slist_prepend (priv->drives, drive);
+
+			g_signal_connect (drive,
+					  "medium-added",
+					  G_CALLBACK (brasero_medium_monitor_medium_added_cb),
+					  object);
+			g_signal_connect (drive,
+					  "medium-removed",
+					  G_CALLBACK (brasero_medium_monitor_medium_removed_cb),
+					  object);
+		}
+		g_free (device);
 	}
+	g_list_foreach (drives, (GFunc) g_object_unref, NULL);
+	g_list_free (drives);
 
-	BRASERO_MEDIA_LOG ("Found %d drives", nb_devices);
-	for (i = 0; i < nb_devices; i++) {
-		/* create the drive */
-		BRASERO_MEDIA_LOG ("Probing %s", devices [i]);
-		drive = brasero_drive_new (devices [i]);
-		priv->drives = g_slist_prepend (priv->drives, drive);
+	volumes = g_volume_monitor_get_volumes (priv->gmonitor);
+	BRASERO_MEDIA_LOG ("Found %d volumes", g_list_length (volumes));
 
-		g_signal_connect (drive,
-				  "medium-added",
-				  G_CALLBACK (brasero_medium_monitor_medium_added_cb),
-				  object);
-		g_signal_connect (drive,
-				  "medium-removed",
-				  G_CALLBACK (brasero_medium_monitor_medium_removed_cb),
-				  object);
+	for (iter = volumes; iter; iter = iter->next) {
+		GVolume *gvolume;
+		gchar *device;
+
+		gvolume = iter->data;
+		device = g_volume_get_identifier (gvolume, G_VOLUME_IDENTIFIER_KIND_UNIX_DEVICE);
+		if (!device)
+			continue;
+
+		/* make sure it isn't already in our list */
+		drive = brasero_medium_monitor_get_drive (object, device);
+		if (drive) {
+			g_free (device);
+			g_object_unref (drive);
+			continue;
+		}
+
+		if (brasero_medium_monitor_is_drive (object, device)) {
+			drive = g_object_new (BRASERO_TYPE_DRIVE,
+			                      "device", device,
+			                      "gdrive", NULL,
+					      NULL);
+			priv->drives = g_slist_prepend (priv->drives, drive);
+
+			g_signal_connect (drive,
+					  "medium-added",
+					  G_CALLBACK (brasero_medium_monitor_medium_added_cb),
+					  object);
+			g_signal_connect (drive,
+					  "medium-removed",
+					  G_CALLBACK (brasero_medium_monitor_medium_removed_cb),
+					  object);
+		}
+
+		g_free (device);
 	}
-	libhal_free_string_array (devices);
+	g_list_foreach (volumes, (GFunc) g_object_unref, NULL);
+	g_list_free (volumes);
+
+	g_signal_connect (priv->gmonitor,
+			  "volume-added",
+			  G_CALLBACK (brasero_medium_monitor_volume_added_cb),
+			  object);
+	g_signal_connect (priv->gmonitor,
+			  "volume-removed",
+			  G_CALLBACK (brasero_medium_monitor_volume_removed_cb),
+			  object);
+	g_signal_connect (priv->gmonitor,
+			  "drive-connected",
+			  G_CALLBACK (brasero_medium_monitor_connected_cb),
+			  object);
+	g_signal_connect (priv->gmonitor,
+			  "drive-disconnected",
+			  G_CALLBACK (brasero_medium_monitor_disconnected_cb),
+			  object);
 
 	/* add fake/file drive */
-	drive = brasero_drive_new (NULL);
+	drive = g_object_new (BRASERO_TYPE_DRIVE,
+	                      "device", NULL,
+	                      NULL);
 	priv->drives = g_slist_prepend (priv->drives, drive);
 
 	return;
@@ -481,6 +700,16 @@ brasero_medium_monitor_finalize (GObject *object)
 
 	priv = BRASERO_MEDIUM_MONITOR_PRIVATE (object);
 
+	if (priv->waiting_removal_id) {
+		g_source_remove (priv->waiting_removal_id);
+		priv->waiting_removal_id = 0;
+	}
+
+	if (priv->waiting_removal) {
+		g_slist_free (priv->waiting_removal);
+		priv->waiting_removal = NULL;
+	}
+
 	if (priv->drives) {
 		g_slist_foreach (priv->drives, (GFunc) g_object_unref, NULL);
 		g_slist_free (priv->drives);
@@ -488,6 +717,18 @@ brasero_medium_monitor_finalize (GObject *object)
 	}
 
 	if (priv->gmonitor) {
+		g_signal_handlers_disconnect_by_func (priv->gmonitor,
+		                                      brasero_medium_monitor_volume_added_cb,
+		                                      object);
+		g_signal_handlers_disconnect_by_func (priv->gmonitor,
+		                                      brasero_medium_monitor_volume_removed_cb,
+		                                      object);
+		g_signal_handlers_disconnect_by_func (priv->gmonitor,
+		                                      brasero_medium_monitor_connected_cb,
+		                                      object);
+		g_signal_handlers_disconnect_by_func (priv->gmonitor,
+		                                      brasero_medium_monitor_disconnected_cb,
+		                                      object);
 		g_object_unref (priv->gmonitor);
 		priv->gmonitor = NULL;
 	}
