@@ -1,20 +1,23 @@
 /* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */
 /*
  * Brasero
- * Copyright (C) Philippe Rouquier 2008 <bonfire-app@wanadoo.fr>
+ * Copyright (C) Philippe Rouquier 2005-2009 <bonfire-app@wanadoo.fr>
  * 
- * Brasero is free software: you can redistribute it and/or modify it
- * under the terms of the GNU General Public License as published by the
- * Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
+ *  Brasero is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
  * 
- * Brasero is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * brasero is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  * See the GNU General Public License for more details.
  * 
- * You should have received a copy of the GNU General Public License along
- * with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * You should have received a copy of the GNU General Public License
+ * along with brasero.  If not, write to:
+ * 	The Free Software Foundation, Inc.,
+ * 	51 Franklin Street, Fifth Floor
+ * 	Boston, MA  02110-1301, USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -46,8 +49,6 @@
 
 #include "brasero-drive.h"
 
-#include "burn-debug.h"
-
 #include "brasero-tags.h"
 #include "brasero-burn.h"
 #include "brasero-track-disc.h"
@@ -425,8 +426,12 @@ brasero_app_save_contents (BraseroApp *app,
 	}
 
 	if (priv->tool_dialog) {
-		if (cancellable)
-			return (brasero_tool_dialog_cancel (BRASERO_TOOL_DIALOG (priv->tool_dialog)) == FALSE);
+		if (cancellable) {
+			if (BRASERO_IS_TOOL_DIALOG (priv->tool_dialog))
+				return (brasero_tool_dialog_cancel (BRASERO_TOOL_DIALOG (priv->tool_dialog)) == FALSE);
+			else if (BRASERO_IS_EJECT_DIALOG (priv->tool_dialog))
+				return (brasero_eject_dialog_cancel (BRASERO_EJECT_DIALOG (priv->tool_dialog)) == FALSE);
+		}
 
 		gtk_widget_destroy (priv->tool_dialog);
 		return FALSE;
@@ -553,7 +558,6 @@ brasero_app_alert (BraseroApp *app,
 						     primary_message,
 						     secondary_message,
 						     type);
-
 	if (!parent && priv->parent) {
 		is_on_top = FALSE;
 
@@ -728,7 +732,9 @@ brasero_app_burn_image (BraseroApp *app,
 	if (uri)
 		brasero_track_image_cfg_set_source (track, uri);
 
-	brasero_burn_session_add_track (BRASERO_BURN_SESSION (session), BRASERO_TRACK (track));
+	brasero_burn_session_add_track (BRASERO_BURN_SESSION (session),
+					BRASERO_TRACK (track),
+					NULL);
 
 	if (brasero_app_burn_options (app, session))
 		brasero_app_burn (app, BRASERO_BURN_SESSION (session));
@@ -746,7 +752,9 @@ brasero_app_copy_disc (BraseroApp *app,
 
 	session = brasero_session_cfg_new ();
 	track = brasero_track_disc_new ();
-	brasero_burn_session_add_track (BRASERO_BURN_SESSION (session), BRASERO_TRACK (track));
+	brasero_burn_session_add_track (BRASERO_BURN_SESSION (session),
+					BRASERO_TRACK (track),
+					NULL);
 
 	/* if a device is specified then get the corresponding medium */
 	if (device) {
@@ -937,16 +945,12 @@ brasero_app_set_toplevel (BraseroApp *app, GtkWindow *window)
 
 	if (!priv->mainwin_running) {
 		if (priv->parent) {
-			gtk_window_set_skip_taskbar_hint (GTK_WINDOW (window), TRUE);
-			gtk_window_set_skip_pager_hint (GTK_WINDOW (window), TRUE);
 			gtk_widget_realize (GTK_WIDGET (window));
-			gtk_window_set_modal (GTK_WINDOW (window), TRUE);
 			gdk_window_set_transient_for (GTK_WIDGET (window)->window, priv->parent);
 		}
 		else {
 			gtk_window_set_skip_taskbar_hint (GTK_WINDOW (window), FALSE);
 			gtk_window_set_skip_pager_hint (GTK_WINDOW (window), FALSE);
-			gtk_window_set_type_hint (GTK_WINDOW (window), GDK_WINDOW_TYPE_HINT_NORMAL);
 			gtk_window_set_position (GTK_WINDOW (window), GTK_WIN_POS_CENTER);
 		}
 	}
@@ -959,7 +963,6 @@ brasero_app_set_toplevel (BraseroApp *app, GtkWindow *window)
 
 		gtk_window_set_skip_taskbar_hint (GTK_WINDOW (window), FALSE);
 		gtk_window_set_skip_pager_hint (GTK_WINDOW (window), FALSE);
-		gtk_window_set_type_hint (GTK_WINDOW (window), GDK_WINDOW_TYPE_HINT_NORMAL);
 		gtk_window_set_position (GTK_WINDOW (window), GTK_WIN_POS_CENTER);
 	}
 
@@ -1441,6 +1444,26 @@ brasero_app_create_mainwin (BraseroApp *app)
 	brasero_app_load_window_state (app);
 }
 
+static UniqueResponse
+brasero_app_unique_message (UniqueApp *uapp,
+			    gint command,
+			    UniqueMessageData *message_data,
+			    guint time,
+			    BraseroApp *app)
+{
+	BraseroAppPrivate *priv;
+
+	priv = BRASERO_APP_PRIVATE (app);
+	if (command == UNIQUE_ACTIVATE) {
+		if (priv->mainwin_running) {
+			gtk_widget_show (priv->mainwin);
+			gtk_window_present (GTK_WINDOW (priv->mainwin));
+		}
+	}
+
+	return UNIQUE_RESPONSE_OK;
+}
+
 gboolean
 brasero_app_run_mainwin (BraseroApp *app)
 {
@@ -1453,6 +1476,10 @@ brasero_app_run_mainwin (BraseroApp *app)
 	gtk_widget_show (GTK_WIDGET (priv->mainwin));
 
 	uapp = unique_app_new ("org.gnome.Brasero", NULL);
+	g_signal_connect (uapp,
+			  "message-received",
+			  G_CALLBACK (brasero_app_unique_message),
+			  app);
 
 	if (unique_app_is_running (uapp))
 	{
