@@ -782,7 +782,7 @@ brasero_data_disc_name_collision_cb (BraseroTrackDataCfg *project,
 		return TRUE;
 
 	/* Translators: %s is the name of the file */
-	string = g_strdup_printf (_("Do you really want to replace \"%s\"?"), name);
+	string = g_strdup_printf (_("Do you want to replace \"%s\"?"), name);
 	dialog = brasero_app_dialog (brasero_app_get_default (),
 				     string,
 				     GTK_BUTTONS_NONE,
@@ -790,7 +790,7 @@ brasero_data_disc_name_collision_cb (BraseroTrackDataCfg *project,
 	g_free (string);
 
 	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
-						  _("A file with the same name is about to be added into the same directory and will replace it if you accept."));
+	                                          _("A file with this name already exists in the folder.  Replacing it will overwrite its content (on the disc only)."));
 
 	/* Translators: Keep means we're keeping the files that already existed
 	 * in the project.
