@@ -945,12 +945,23 @@ brasero_project_is_valid (BraseroSessionCfg *session,
 		project->priv->empty = TRUE;
 	}
 	else if (valid == BRASERO_SESSION_INSUFFICIENT_SPACE) {
+		goffset min_disc_size;
+		goffset available_space;
+
 		project->priv->oversized = TRUE;
 		project->priv->empty = FALSE;
 
+		min_disc_size = brasero_session_span_get_max_space (BRASERO_SESSION_SPAN (session));
+
+		/* One rule should be that the maximum batch size should not exceed the disc size
+		 * FIXME: we could change it into a dialog telling the user what is the maximum
+		 * size required. */
+		available_space = brasero_burn_session_get_available_medium_space (BRASERO_BURN_SESSION (session));
+
 		/* Here there is an alternative: we may be able to span the data
 		 * across multiple media. So try that. */
-		if (brasero_session_span_possible (BRASERO_SESSION_SPAN (project->priv->session)) == BRASERO_BURN_RETRY) {
+		if (available_space > min_disc_size
+		&& brasero_session_span_possible (BRASERO_SESSION_SPAN (session)) == BRASERO_BURN_RETRY) {
 			GtkWidget *message;
 
 			message = brasero_notify_message_add (BRASERO_NOTIFY (project->priv->message),
@@ -1412,6 +1423,7 @@ brasero_project_drive_properties (BraseroProject *project)
 static gboolean
 brasero_project_image_properties (BraseroProject *project)
 {
+	BraseroTrackType *track_type;
 	GtkResponseType answer;
 	GtkWidget *button;
 	GtkWidget *dialog;
@@ -1440,8 +1452,26 @@ brasero_project_image_properties (BraseroProject *project)
 
 	brasero_image_properties_set_session (BRASERO_IMAGE_PROPERTIES (dialog), project->priv->session);
 
+	track_type = brasero_track_type_new ();
+
+	brasero_burn_session_get_input_type (BRASERO_BURN_SESSION (project->priv->session), track_type);
+	if (brasero_track_type_get_has_stream (track_type)
+	&& BRASERO_STREAM_FORMAT_HAS_VIDEO (brasero_track_type_get_stream_format (track_type))) {
+		GtkWidget *box;
+		GtkWidget *options;
+
+		/* create video widget */
+		options = brasero_video_options_new (BRASERO_BURN_SESSION (project->priv->session));
+		gtk_widget_show (options);
+
+		box = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
+		gtk_box_pack_end (GTK_BOX (box), options, FALSE, TRUE, 0);
+	}
+
+	brasero_track_type_free (track_type);
+
 	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_OK);
-	gtk_widget_show_all (dialog);
+	gtk_widget_show (dialog);
 
 	/* launch the dialog */
 	answer = gtk_dialog_run (GTK_DIALOG (dialog));
@@ -2004,6 +2034,9 @@ brasero_project_add_uris_cb (GtkAction *action,
 	gtk_file_filter_add_mime_type (filter, "application/x-flash-video");
 	gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (project->priv->chooser), filter);
 
+	if (BRASERO_IS_VIDEO_DISC (project->priv->current))
+		gtk_file_chooser_set_filter (GTK_FILE_CHOOSER (project->priv->chooser), filter);
+
 	filter = gtk_file_filter_new ();
 	/* Translators: this is an image, a picture, not a "Disc Image" */
 	gtk_file_filter_set_name (filter, C_("picture", "Image files"));
